#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import sys
import os
from gettext import gettext as _

sys.path.append(os.path.join(os.path.dirname(__file__), '..'))

from gi import require_version
require_version("Gtk", "3.0")

from gi.repository import Gio
from gi.repository import Gtk
from gi.repository import GLib

from gasimporter.window import ApplicationWindow

class Application(Gtk.Application):

    def __init__(self):
        Gtk.Application.__init__(self,
                                 application_id="org.gas.importer",
                                 flags=Gio.ApplicationFlags.FLAGS_NONE)

        self.window = None

    def do_startup(self):
        Gtk.Application.do_startup(self)
        self._setup()

    def _setup(self):
        self._create_actions()
        self._create_app_menu()

    def do_activate(self):
        self.create_main_window()

    def create_main_window(self):
        if self.window:
            return
        self.window = ApplicationWindow(self)
        self.add_window(self.window)
        self.window.show()

    """
    Create acclerator actions for app-menu
    """
    def _create_actions(self):
        action = Gio.SimpleAction.new('settings', None)
        action.connect('activate', self.on_setting)
        self.set_accels_for_action('app.settings', ["<Control>s"])
        self.add_action(action)
        #ShortcutsWindow.add_action("app.settings", _("Edit settings"))

        action = Gio.SimpleAction.new("about", None)
        action.connect("activate", self.on_about)
        self.set_accels_for_action('app.about', ["F3"])
        self.add_action(action)

        action = Gio.SimpleAction.new('shortcuts', None)
        action.connect('activate', self.on_shortcut)
        self.set_accels_for_action('app.shortcuts', ["F2"])
        self.add_action(action)

        action = Gio.SimpleAction.new('help', None)
        action.connect('activate', self.on_help)
        self.set_accels_for_action('app.help', ["F1"])
        self.add_action(action)

        action = Gio.SimpleAction.new("quit", None)
        action.connect("activate", self.on_quit)
        self.set_accels_for_action('app.quit', ["<Control>q"])
        self.add_action(action)

    def _create_app_menu(self):
        builder = Gtk.Builder()
        builder.add_from_file('../data/ui/app-menu.ui')
        menu = builder.get_object('app-menu')

        self.set_app_menu(menu)

    def on_setting(sef, action, param):
        pass

    def on_about(self, action, param):
        builder = Gtk.Builder()
        builder.add_from_file('../data/ui/about.ui')
        dialog = builder.get_object('about_dialog')
        dialog.set_transient_for(self.window)
        dialog.show()

    def on_shortcut(self, action, param):
        builder = Gtk.Builder()
        builder.add_from_file('../data/ui/shortcuts.ui')
        dialog = builder.get_object('shortcuts')
        dialog.set_transient_for(self.window)
        dialog.show()

    def on_help(self, action, param):
        pass

    def on_quit(self, action, param):
        self.quit()

if __name__ == '__main__':
    app = Application()
    app.run(sys.argv)
